Data
=======

Welcome to PUNCH data!

Our latest version of data is 0j (learn more about `data versions <data_versions.html>`_).
We will begin providing browse data and movies soon.

PUNCH is still being calibrated, but you can take a look at the most up to date data
through the `Get Data <https://punch.space.swri.edu/punch_science_getdata.php>`_ page on our PUNCH website.
The most commonly used data products are L3_PAM (polarized) and L3_CAM (clear) low-noise mosaics.

For more information about how to download data, see this `data access <access.html>`_ page.

For more information about data analysis tools, see the `example gallery <../auto_examples/index.html>`_.

For information on more data products, read this `data overview <data_overview.html>`_.

.. image:: example.png
   :alt: An example PUNCH image

.. toctree::
   :hidden:

   data_overview
   access
   data_object
   data_codes
   metadata
   data_versions
